require "yaml"
require "active_support/core_ext/string/strip"
require "active_support/core_ext/hash/except"
require "active_support/core_ext/hash/keys"

CREDENTIAL_FILES = [:dropbox, :app_folder].inject({}) do |hash, access_type|
  hash.update(access_type => File.join(Bundler.root, "spec/config/#{access_type}.yml"))
end

CREDENTIALS = [:dropbox, :app_folder].inject({}) do |hash, access_type|
  begin
    content = File.read(CREDENTIAL_FILES[access_type])
    credentials = YAML.load(content).symbolize_keys
    hash.update(access_type => credentials)
  rescue Errno::ENOENT
    $stderr.puts <<-EOS.strip_heredoc

      Some of the credential files were not found.  Please, copy spec/config/dropbox.yml.example
      into spec/config/dropbox.yml, and fill it with credentials of your Dropbox app with "full dropbox"
      access you intend to use. And the same for spec/config/app_folder.yml and "app folder" access.

      Make use of the "dropbox:authorize" Rake task.

    EOS
    exit
  end
end
